@@ -4,9 +4,6 @@
 #' Specify a country or vector of countries in order to map them (the default is to map all countries).
 #' Various other options are available for tuning the plot further.
 #' @param year Numeric, indicating the year of data to map. Defaults to 2016.
-#' @param trans A character string specifying the transform to use on the mapped metric. Defaults to no 
-#' transform ("identity"). Other options include log scaling ("log") and log base 10 scaling
-#' ("log10"). For a complete list of options see \code{ggplot2::continous_scale}.
 #' @inheritParams plot_tb_burden
 #' @seealso plot_tb_burden plot_tb_burden_overview get_tb_burden search_data_dict
 #' @return A plot of TB Incidence Rates by Country
@@ -19,13 +16,17 @@
 #' @importFrom ggthemes theme_map
 #' @importFrom purrr map
 #' @importFrom plotly ggplotly
+#' @importFrom scales percent
 #' @examples
 #' 
 #' ## Map raw incidence rates
-#' map_tb_burden(download_data = TRUE, save = TRUE)
+#' map_tb_burden()
 #' 
-#' ## Map log scaled incidence rates
-#' map_tb_burden(trans = "log")
+#' ## Map log10 scaled incidence rates
+#' map_tb_burden(trans = "log10")
+#' 
+#' ## Map percentage annual change in incidence rates
+#' map_tb_burden(annual_change = TRUE)
 #' 
 #' ## Find variables relating to mortality in the WHO dataset
 #' search_data_dict(def = "mortality")
@@ -39,10 +40,11 @@ map_tb_burden <- function(df = NULL, dict = NULL,
                            countries = NULL,
                            compare_to_region = FALSE,
                            facet = NULL, year = 2016,
+                           annual_change = FALSE,
                            trans = "identity",
                            interactive = FALSE, 
-                           download_data = FALSE,
-                           save = FALSE,
+                           download_data = TRUE,
+                           save = TRUE,
                            burden_save_name = "TB_burden",
                            dict_save_name = "TB_data_dict",
                            verbose = TRUE, ...) {
@@ -56,16 +58,14 @@ map_tb_burden <- function(df = NULL, dict = NULL,
                              compare_to_region = compare_to_region,
                              facet = facet,
                              download_data = download_data,
+                             trans = trans,
+                             annual_change = annual_change,
                              save = save,
                              burden_save_name = burden_save_name,
                              dict_save_name = dict_save_name,
                              verbose = verbose)
   
   ## Bind in world data
-  if (trans != "identity") {
-    df_prep$metric_label <- paste0(df_prep$metric_label, "(", trans, ")")
-  }
-  
   df_prep$df <- df_prep$df %>% 
     left_join(getTBinR::who_shapefile, c("iso3" = "id")) %>% 
     filter(year %in% sel_year)
@@ -84,13 +84,23 @@ map_tb_burden <- function(df = NULL, dict = NULL,
                  aes_string(x = "long", 
                             y = "lat", 
                             text = "country",
-                            fill = paste0("`",df_prep$metric_label, "`"))) +
+                            fill = paste0("`", df_prep$metric_label, "`"),
+                            key = "country")) +
     geom_polygon(aes_string(group = "group")) + 
-    scale_fill_viridis(end = 0.95, trans = trans, direction = -1, discrete = FALSE) +
     coord_equal() +
     ggthemes::theme_map() +
     theme(legend.position = "bottom") 
   
+  if (annual_change) {
+    plot <- plot +
+      scale_fill_viridis(end = 0.95, trans = trans, 
+                         direction = -1, discrete = FALSE,
+                         labels = percent)
+  }else{
+    plot <- plot +
+      scale_fill_viridis(end = 0.95, trans = trans, 
+                         direction = -1, discrete = FALSE)
+  }
   if (!is.null(df_prep$facet)) {
     plot <- plot + 
       facet_wrap(df_prep$facet, scales = "fixed")
