@@ -5,7 +5,8 @@
 #' Various other options are available for tuning the plot further.
 #' @param conf Character vector specifying the name variations to use to specify the upper
 #' and lower confidence intervals. Defaults to c("_lo", "_hi"), if set to \code{NULL}
-#' then no confidence intervals are shown.
+#' then no confidence intervals are shown. When \code{annual_change = TRUE} the confidence 
+#' intervals represent the annual percentage change in the metrics confidence intervals.
 #' @param scales Character string, see ?ggplot2::facet_wrap for details. Defaults to "fixed",
 #' alternatives are "free_y", "free_x", or "free".
 #' @param interactive Logical, defaults to \code{FALSE}. If \code{TRUE} then an interactive plot is 
@@ -17,24 +18,29 @@
 #' @import ggplot2
 #' @import magrittr
 #' @importFrom dplyr filter
+#' @importFrom scales percent
 #' @importFrom purrr map
 #' @importFrom plotly ggplotly
 #' @importFrom viridis  scale_fill_viridis  scale_colour_viridis
 #' @examples
 #' 
 #' ## Get the WHO TB burden data and the data dictionary
-#' tb_burden <- get_tb_burden(download_data = TRUE, save = TRUE)
-#' dict <- get_data_dict(download_data = TRUE, save = TRUE)
+#' tb_burden <- get_tb_burden()
+#' dict <- get_data_dict()
 #' 
 #' ## Get a random sample of 9 countries
 #' sample_countries <- sample(unique(tb_burden$country), 9)
 #' 
 #' ## Plot incidence rates in these countries
 #' plot_tb_burden(df = tb_burden, dict = dict, facet = "country", countries = sample_countries)
-#' 
+#'  
 #' ## Use data caching to plot incidence rates with free y scales
 #' plot_tb_burden(facet = "country", countries = sample_countries, scales = "free_y")
 #'  
+#' ## Plot annual percentage change in incidence rates in selected countries
+#' plot_tb_burden(df = tb_burden, dict = dict, facet = "country", scales = "free_y", 
+#'                countries = sample_countries, annual_change = TRUE, conf = NULL)
+#'                
 #' ## Find variables relating to mortality in the WHO dataset
 #' search_data_dict(def = "mortality")
 #' ## Plot mortality rates (exc HIV) - without progress messages
@@ -46,10 +52,12 @@ plot_tb_burden <- function(df = NULL, dict = NULL,
                            metric_label = NULL,
                            conf = c("_lo", "_hi"), countries = NULL,
                            compare_to_region = FALSE,
-                           facet = NULL, scales = "fixed",
+                           facet = NULL, annual_change = FALSE,
+                           trans = "identity",
+                           scales = "fixed",
                            interactive = FALSE,
-                           download_data = FALSE,
-                           save = FALSE,
+                           download_data = TRUE,
+                           save = TRUE,
                            burden_save_name = "TB_burden",
                            dict_save_name = "TB_data_dict",
                            verbose = TRUE, ...) {
@@ -57,10 +65,13 @@ plot_tb_burden <- function(df = NULL, dict = NULL,
   df_prep <- prepare_df_plot(df = df,
                              dict = dict,
                              metric = metric,
+                             conf = conf,
                              metric_label = metric_label,
                              countries = countries,
                              compare_to_region = compare_to_region,
                              facet = facet,
+                             trans = trans,
+                             annual_change = annual_change,
                              download_data = download_data,
                              save = save,
                              burden_save_name = burden_save_name,
@@ -69,7 +80,8 @@ plot_tb_burden <- function(df = NULL, dict = NULL,
   
   country <- NULL
   
-  plot <- ggplot(df_prep$df, aes_string(x = "year", y = metric, col = "country", fill = "country")) +
+  plot <- ggplot(df_prep$df, aes_string(x = "year", y = paste0("`", df_prep$metric_label, "`"),
+                                        col = "country", fill = "country")) +
     geom_line()
   
   if (!is.null(conf)) {
@@ -86,13 +98,21 @@ plot_tb_burden <- function(df = NULL, dict = NULL,
     theme(legend.position = "none") +
     labs(x = "Year", y = df_prep$metric_label)
   
+  if (annual_change) {
+    plot <- plot +
+      scale_y_continuous(labels = percent, trans = trans)
+  }else{
+    plot <- plot + 
+      scale_y_continuous(trans = trans)
+  }
+  
   if (!is.null(df_prep$facet)) {
     plot <- plot + 
       facet_wrap(df_prep$facet, scales = scales)
   }
   
   if (interactive) {
-    plot <- plotly::ggplotly(plot)
+    plot <- ggplotly(plot)
   }
   
   return(plot)
